@@ -1,20 +1,15 @@
 #' @title Retrieve value labels of labelled data
 #' @name get_labels
 #'
-#' @description This function retrieves the value labels of labelled data, which
-#'                was created with the \pkg{labelled} or \pkg{haven} package, or
-#'                imported from SPSS, SAS or STATA files (via \code{\link{read_spss}},
-#'                \code{\link{read_sas}} or \code{\link{read_stata}}) and
-#'                \itemize{
-#'                  \item if \code{x} is a data frame or list of variables, returns all variables' value labels as \code{\link{list}}
-#'                  \item or, if \code{x} is a vector, returns the value labels as string.
-#'                  }
+#' @description This function returns the value labels of labelled data.
 #'
-#' @seealso See package vignettes or \href{http://www.strengejacke.de/sjPlot/}{online documentation}
-#'            for more details; \code{\link{set_labels}} to manually set value labels, \code{\link{get_label}}
-#'            to get variable labels and \code{\link{get_values}} to retrieve value label associated values.
+#' @seealso See \href{http://www.strengejacke.de/sjPlot/}{online documentation}
+#'            for more details; \code{\link{set_labels}} to manually set value
+#'            labels, \code{\link{get_label}} to get variable labels and
+#'            \code{\link{get_values}} to retrieve the values associated
+#'            with value labels.
 #'
-#' @param x \code{data.frame} with variables that have value label attributes (e.g.
+#' @param x A data frame with variables that have value label attributes (e.g.
 #'          from an imported SPSS, SAS or STATA data set, via \code{\link{read_spss}},
 #'          \code{\link{read_sas}} or \code{\link{read_stata}}); a variable
 #'          (vector) with value label attributes; or a \code{list} of variables
@@ -36,17 +31,19 @@
 #'          should be included in the return value or not. By default, labelled
 #'          (tagged) missing values are not returned. See \code{\link{get_na}}
 #'          for more details on tagged NA values.
+#' @param drop.unused Logical, if \code{TRUE}, unused labels will be removed from
+#'          the return value.
 #' @return Either a list with all value labels from all variables if \code{x}
 #'           is a \code{data.frame} or \code{list}; a string with the value
 #'           labels, if \code{x} is a variable;
 #'           or \code{NULL} if no value label attribute was found.
 #'
-#' @details This package can add (and read) value and variable labels either in \pkg{foreign}
+#' @details This package can add (and read) value and variable labels either in \CRANpkg{foreign}
 #'            package style (attributes are named \emph{value.labels} and \emph{variable.label})
-#'            or in \pkg{haven} package style (attributes are named \emph{labels} and
+#'            or in \CRANpkg{haven} package style (attributes are named \emph{labels} and
 #'            \emph{label}). By default, the \pkg{haven} package style is used.
 #'            \cr \cr
-#'            Working with labelled data is a key feature of the \pkg{sjPlot} package,
+#'            Working with labelled data is a key feature of the \CRANpkg{sjPlot} package,
 #'            which accesses these attributes to automatically read label attributes
 #'            for labelling axis categories and titles or table rows and columns
 #'            in graphical or tabular outputs.
@@ -59,27 +56,23 @@
 #'            when saving data, e.g. to SPSS (see \code{\link{write_spss}}),
 #'            which means that the written SPSS file contains proper labels
 #'            for each variable.
-#'            \cr \cr
-#'            You can set a default label style (i.e. the names of the label
-#'            attributes, see above) via \code{options(value_labels = "haven")}
-#'            or \code{options(value_labels = "foreign")}.
 #'
 #' @note This function works with vectors that have value and variable
 #'        label attributes (as provided, for instance, by \code{\link[haven]{labelled}}
 #'        objects). Adding label attributes is automatically done when importing data sets
 #'        with the \code{\link{read_spss}}, \code{\link{read_sas}} or \code{\link{read_stata}}
 #'        functions. Labels can also manually be added using the \code{\link{set_labels}}
-#'        and \code{\link{set_label}} functions. If vectors \strong{do not} have
-#'        label attributes, either factor-\code{\link{levels}} or the numeric values
+#'        and \code{\link{set_label}} functions. If vectors \emph{do not} have
+#'        label attributes, either factor-levels or the numeric values
 #'        of the vector are returned as labels.
 #'        \cr \cr
-#'        Most functions of the \pkg{sjPlot} package access value and variable label
-#'        attributes to automatically detect labels in order to set them as axis,
-#'        legend or title labels in plots (\code{sjp.}-functions) respectively as
-#'        column or row headers in table outputs (\code{sjt.}-functions). See
+#'        Most functions of the \CRANpkg{sjPlot} package make use of value and variable
+#'        labels to automatically label axes, legend or title labels in plots
+#'        (\code{sjp.}-functions) respectively column or row headers in table
+#'        outputs (\code{sjt.}-functions). See
 #'        \href{http://www.strengejacke.de/sjPlot/datainit/}{this} and
 #'        \href{http://www.strengejacke.de/sjPlot/labelleddata/}{this}
-#'        online manuals for more details.
+#'        online manual for more details.
 #'
 #' @examples
 #' # import SPSS data set
@@ -145,38 +138,50 @@
 #' x
 #' get_labels(x, include.values = "n", drop.na = FALSE)
 #'
+#'
+#' # create vector with unused labels
+#' data(efc)
+#' set_labels(efc$e42dep) <- c("independent" = 1, "dependent" = 4, "not used" = 5)
+#' get_labels(efc$e42dep)
+#' get_labels(efc$e42dep, drop.unused = TRUE)
+#' get_labels(efc$e42dep, include.non.labelled = TRUE, drop.unused = TRUE)
+#'
 #' @export
 get_labels <- function(x, attr.only = FALSE, include.values = NULL,
-                       include.non.labelled = FALSE, drop.na = TRUE) {
+                       include.non.labelled = FALSE, drop.na = TRUE, drop.unused = FALSE) {
   UseMethod("get_labels")
 }
 
 #' @export
 get_labels.data.frame <- function(x, attr.only = FALSE, include.values = NULL,
-                                  include.non.labelled = FALSE, drop.na = TRUE) {
+                                  include.non.labelled = FALSE, drop.na = TRUE,
+                                  drop.unused = FALSE) {
   lapply(x, FUN = get_labels_helper, attr.only = attr.only, include.values = include.values,
-         include.non.labelled = include.non.labelled, drop.na = drop.na)
+         include.non.labelled = include.non.labelled, drop.na = drop.na, drop.unused = drop.unused)
 }
 
 #' @export
 get_labels.list <- function(x, attr.only = FALSE, include.values = NULL,
-                                  include.non.labelled = FALSE, drop.na = TRUE) {
+                            include.non.labelled = FALSE, drop.na = TRUE, drop.unused = FALSE) {
   lapply(x, FUN = get_labels_helper, attr.only = attr.only, include.values = include.values,
-         include.non.labelled = include.non.labelled, drop.na = drop.na)
+         include.non.labelled = include.non.labelled, drop.na = drop.na, drop.unused = drop.unused)
 }
 
 #' @export
 get_labels.default <- function(x, attr.only = FALSE, include.values = NULL,
-                                  include.non.labelled = FALSE, drop.na = TRUE) {
+                               include.non.labelled = FALSE, drop.na = TRUE,
+                               drop.unused = FALSE) {
   get_labels_helper(x, attr.only = attr.only, include.values = include.values,
-                    include.non.labelled = include.non.labelled, drop.na = drop.na)
+                    include.non.labelled = include.non.labelled, drop.na = drop.na,
+                    drop.unused = drop.unused)
 }
 
 # Retrieve value labels of a data frame or variable
 # See 'get_labels'
 #' @importFrom haven is_tagged_na na_tag
-get_labels_helper <- function(x, attr.only, include.values, include.non.labelled, drop.na) {
+get_labels_helper <- function(x, attr.only, include.values, include.non.labelled, drop.na, drop.unused) {
   labels <- NULL
+  add_vals <- NULL
   # get label attribute, which may differ depending on the package
   # used for reading the data
   attr.string <- getValLabelAttribute(x)
@@ -202,6 +207,8 @@ get_labels_helper <- function(x, attr.only, include.values, include.non.labelled
     if (drop.na) lab <- lab[!haven::is_tagged_na(lab)]
     # check if we have anything
     if (!is.null(lab) && length(lab) > 0) {
+      # sort labels
+      lab <- lab[order(lab)]
       # retrieve values associated with labels. for character vectors
       # or factors with character levels, these values are character values,
       # else, they are numeric values
@@ -267,6 +274,15 @@ get_labels_helper <- function(x, attr.only, include.values, include.non.labelled
   }
   # foreign? then reverse order
   if (is_foreign(attr.string)) labels <- rev(labels)
+
+  # drop unused labels with no values in data
+  if (drop.unused) {
+    # get all values
+    av <- c(get_values(x, drop.na = drop.na), add_vals)
+    # drop unused values
+    if (!is.null(av)) labels <- labels[sort(av) %in% names(table(x))]
+  }
+
   # return them
   return(labels)
 }
